@@ -416,6 +416,36 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
+        ActiveBlock::StorageClasses => {
+          if let Some(res) = handle_block_action(key, &mut app.data.storage_classes) {
+            let _ok = handle_describe_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "storageclass".to_owned(),
+                value: res.name.to_owned(),
+                ns: None,
+              },
+            )
+            .await;
+          }
+        }
+        ActiveBlock::Roles => {
+          if let Some(res) = handle_block_action(key, &mut app.data.roles) {
+            let _ok = handle_describe_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "roles".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
         ActiveBlock::Contexts | ActiveBlock::Utilization | ActiveBlock::Help => { /* Do nothing */ }
       }
     }
@@ -477,6 +507,8 @@ async fn handle_block_scroll(app: &mut App, up: bool, is_mouse: bool, page: bool
     ActiveBlock::CronJobs => app.data.cronjobs.handle_scroll(up, page),
     ActiveBlock::Secrets => app.data.secrets.handle_scroll(up, page),
     ActiveBlock::RplCtrl => app.data.rpl_ctrls.handle_scroll(up, page),
+    ActiveBlock::StorageClasses => app.data.storage_classes.handle_scroll(up, page),
+    ActiveBlock::Roles => app.data.roles.handle_scroll(up, page),
     ActiveBlock::Contexts => app.data.contexts.handle_scroll(up, page),
     ActiveBlock::Utilization => app.data.metrics.handle_scroll(up, page),
     ActiveBlock::Help => app.help_docs.handle_scroll(up, page),
