@@ -27,6 +27,8 @@ pub enum IoEvent {
   GetCronJobs,
   GetSecrets,
   GetReplicationControllers,
+  GetStorageClasses,
+  GetRoles,
   GetMetrics,
   RefreshClient,
 }
@@ -154,6 +156,12 @@ impl<'a> Network<'a> {
       IoEvent::GetMetrics => {
         self.get_utilizations().await;
       }
+      IoEvent::GetStorageClasses => {
+        self.get_storage_classes().await;
+      }
+      IoEvent::GetRoles => {
+        self.get_roles().await;
+      }
     };
 
     let mut app = self.app.lock().await;
